## Overview

Include files for Intel® Threading Building Blocks (Intel® TBB).

## Directories

tbb
  Include files for Intel TBB classes and functions.
serial/tbb
  Include files for a sequential implementation of the parallel_for algorithm.

Up to parent directory

Copyright © 2005-2018 Intel Corporation. All Rights Reserved.

Intel is a registered trademark or trademark of Intel Corporation or its subsidiaries in the United States and other countries.

* Other names and brands may be claimed as the property of others.